##  Visualize Changes with Reports
Use the available reports to get a high-level understanding of the current and future states of your application landscape. You can focus on specific initiatives to assess if your planned transformation roadmap is meeting the goals and objectives you had set when starting out.
Application Landscape Report Goal | Settings | Example
---|---|---
Understand the current or future state of the application landscape |
  * Filter by: Modernization initiative
  * View: Impact Type

To learn more about impacts, visit [Impacts](https://help.sap.com/docs/leanix/ea/impacts?locale=en-US&state=PRODUCTION&version=CLOUD "Impacts detail the changes at attribute and relation levels. Learn how to manage these Impacts in SAP LeanIX Architecture and Road Map Planning.").  |  ![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2f22955be84742afb31f8c75aeaa4b31_LowRes.png)
Track how hosting types evolve over the course of your modernization (for example, on-premise to SaaS) |
  * Filter by: Parent or child initiative
  * View: Hosting Type
  * Time slider: Add parent initiative with milestones
  * Use the time slider to select a point in time or milestone. Hold **shift** key and select two points on the time slider

|  ![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiod4986b5a14b94d6d96823ccdd4754d68_LowRes.png)
Present data to stakeholders |
  * Filter by: Parent or child initiative
  * View: Hosting Type or Lifecycle
  * Layout Mode: Rolled up
  * Time slider: Add parent initiative with milestones

|  ![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loioce95391e6168422dba9f1751a3146e36_LowRes.png)


Circle Map Report Goal | Settings | Example
---|---|---
Understand how application interfaces are affected by transformation. |
  * Filter by: Parent or child initiative
  * Time slider: Add parent initiative with milestones
  * Use the time slider to select a point in time or milestone. Hold **shift** key and select two points on the time slider

|  ![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio10f8fa23eb744366b0f5c86c1ecd0a1e_LowRes.png)


